@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -29,7 +30,6 @@
 
 #include <glib.h>
 
-#include "egg-debug.h"
 #include "egg-array-float.h"
 
 /**
@@ -150,7 +150,7 @@ egg_array_float_compute_gaussian (guint length, gfloat sigma)
 	half_length = (length / 2) + 1;
 	for (i=0; i<half_length; i++) {
 		division = half_length - (i + 1);
-	egg_debug ("half_length=%i, div=%f, sigma=%f", half_length, division, sigma);
+	g_debug ("half_length=%i, div=%f, sigma=%f", half_length, division, sigma);
 		g_array_index (array, gfloat, i) = egg_array_float_guassian_value (division, sigma);
 	}
 
@@ -163,7 +163,7 @@ egg_array_float_compute_gaussian (guint length, gfloat sigma)
 	/* make sure we get an accurate gaussian */
 	value = egg_array_float_sum (array);
 	if (fabs (value - 1.0f) > 0.01f) {
-		egg_warning ("got wrong sum (%f), perhaps sigma too high for size?", value);
+		g_warning ("got wrong sum (%f), perhaps sigma too high for size?", value);
 		egg_array_float_free (array);
 		array = NULL;
 	}
@@ -207,7 +207,7 @@ egg_array_float_print (EggArrayFloat *array)
 	length = array->len;
 	/* debug out */
 	for (i=0; i<length; i++)
-		egg_debug ("[%i]\tval=%f", i, g_array_index (array, gfloat, i));
+		g_debug ("[%i]\tval=%f", i, g_array_index (array, gfloat, i));
 	return TRUE;
 }
 
@@ -432,7 +432,7 @@ egg_array_float_test (gpointer data)
 	egg_array_float_set (array, 8, 31.0);
 	egg_array_float_set (array, 9, 30.0);
 	kernel = egg_array_float_remove_outliers (array, 3, 10.0);
-	if (kernel != NULL && kernel->len == 10) 
+	if (kernel != NULL && kernel->len == 10)
 		egg_test_success (test, "got correct length outlier array");
 	else
 		egg_test_failed (test, "got gaussian array length (%i)", array->len);
@@ -461,7 +461,7 @@ egg_array_float_test (gpointer data)
 	egg_array_float_set (array, 8, 20.0);
 	egg_array_float_set (array, 9, 50.0);
 	kernel = egg_array_float_remove_outliers (array, 3, 20.0);
-	if (kernel != NULL && kernel->len == 10) 
+	if (kernel != NULL && kernel->len == 10)
 		egg_test_success (test, "got correct length outlier array");
 	else
 		egg_test_failed (test, "got gaussian array length (%i)", array->len);
@@ -514,7 +514,7 @@ egg_array_float_test (gpointer data)
 	sigma = 1.1;
 	egg_test_title (test, "get inprecise gaussian array (%i), sigma %f", size, sigma);
 	kernel = egg_array_float_compute_gaussian (size, sigma);
-	if (kernel == NULL) 
+	if (kernel == NULL)
 		egg_test_success (test, NULL);
 	else {
 		egg_test_failed (test, "got gaussian array length (%i)", array->len);
@@ -526,7 +526,7 @@ egg_array_float_test (gpointer data)
 	sigma = 1.1;
 	egg_test_title (test, "get gaussian-9 array (%i), sigma %f", size, sigma);
 	kernel = egg_array_float_compute_gaussian (size, sigma);
-	if (kernel != NULL && kernel->len == size) 
+	if (kernel != NULL && kernel->len == size)
 		egg_test_success (test, "got correct length gaussian array");
 	else
 		egg_test_failed (test, "got gaussian array length (%i)", array->len);
