@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2010 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -40,7 +41,7 @@
  * gcm_backlight_helper_get_best_backlight:
  **/
 static gchar *
-gcm_backlight_helper_get_best_backlight ()
+gcm_backlight_helper_get_best_backlight (void)
 {
 	gchar *filename;
 	guint i;
