@@ -3,6 +3,7 @@
  * Copyright (C) 2005 Jaap Haitsma <jaap@haitsma.org>
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  * Copyright (C) 2005-2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -32,7 +33,6 @@
 #define UPOWER_ENABLE_DEPRECATED
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
 #include "egg-console-kit.h"
 
 #include "gpm-tray-icon.h"
@@ -41,6 +41,10 @@
 #include "gpm-icon-names.h"
 #include "gpm-brightness.h"
 
+#define GET_WIDGET(x) (GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, (x))))
+#define GET_NOTEBOOK(x) (GTK_NOTEBOOK (gtk_builder_get_object (prefs->priv->builder, (x))))
+#define GET_WINDOW(x) (GTK_WINDOW (gtk_builder_get_object (prefs->priv->builder, (x))))
+
 static void gpm_prefs_finalize (GObject *object);
 
 struct GpmPrefsPrivate
@@ -109,7 +113,7 @@ void
 gpm_prefs_activate_window (GtkApplication *app, GpmPrefs *prefs)
 {
 	GtkWindow *window;
-	window = GTK_WINDOW (gtk_builder_get_object (prefs->priv->builder, "dialog_preferences"));
+	window = GET_WINDOW ("dialog_preferences");
 	gtk_application_add_window (GTK_APPLICATION (app), window);
 	gtk_window_present (window);
 }
@@ -122,7 +126,7 @@ gpm_prefs_activate_window (GtkApplication *app, GpmPrefs *prefs)
 static void
 gpm_prefs_help_cb (GtkWidget *widget, GpmPrefs *prefs)
 {
-	egg_debug ("emitting action-help");
+	g_debug ("emitting action-help");
 	g_signal_emit (prefs, signals [ACTION_HELP], 0);
 }
 
@@ -186,7 +190,7 @@ gpm_prefs_action_time_changed_cb (GtkWidget *widget, GpmPrefs *prefs)
 	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 	value = values[active];
 
-	egg_debug ("Changing %s to %i", gpm_pref_key, value);
+	g_debug ("Changing %s to %i", gpm_pref_key, value);
 	g_settings_set_int (prefs->priv->settings, gpm_pref_key, value);
 }
 
@@ -218,7 +222,7 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 	GPtrArray *array;
 	GpmActionPolicy *actions_added;
 
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, widget_name));
+	widget = GET_WIDGET (widget_name);
 
 	value = g_settings_get_enum (prefs->priv->settings, gpm_pref_key);
 	is_writable = g_settings_is_writable (prefs->priv->settings, gpm_pref_key);
@@ -233,14 +237,14 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 	for (i=0; actions[i] != -1; i++) {
 		policy = actions[i];
 		if (policy == GPM_ACTION_POLICY_SHUTDOWN && !prefs->priv->can_shutdown) {
-			egg_debug ("Cannot add option, as cannot shutdown.");
+			g_debug ("Cannot add option, as cannot shutdown.");
 		} else if (policy == GPM_ACTION_POLICY_SHUTDOWN && prefs->priv->can_shutdown) {
 			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT (widget), _("Shutdown"));
 			g_ptr_array_add(array, GINT_TO_POINTER (policy));
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND && !prefs->priv->can_suspend) {
-			egg_debug ("Cannot add option, as cannot suspend.");
+			g_debug ("Cannot add option, as cannot suspend.");
 		} else if (policy == GPM_ACTION_POLICY_HIBERNATE && !prefs->priv->can_hibernate) {
-			egg_debug ("Cannot add option, as cannot hibernate.");
+			g_debug ("Cannot add option, as cannot hibernate.");
 		} else if (policy == GPM_ACTION_POLICY_SUSPEND && prefs->priv->can_suspend) {
 			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT (widget), _("Suspend"));
 			g_ptr_array_add (array, GINT_TO_POINTER (policy));
@@ -257,7 +261,7 @@ gpm_prefs_setup_action_combo (GpmPrefs *prefs, const gchar *widget_name,
 			gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT (widget), _("Do nothing"));
 			g_ptr_array_add(array, GINT_TO_POINTER (policy));
 		} else {
-			egg_warning ("Unknown action read from settings: %i", policy);
+			g_warning ("Unknown action read from settings: %i", policy);
 		}
 	}
 
@@ -296,7 +300,7 @@ gpm_prefs_setup_time_combo (GpmPrefs *prefs, const gchar *widget_name,
 	gboolean is_writable;
 	GtkWidget *widget;
 
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, widget_name));
+	widget = GET_WIDGET (widget_name);
 
 	value = g_settings_get_int (prefs->priv->settings, gpm_pref_key);
 	is_writable = g_settings_is_writable (prefs->priv->settings, gpm_pref_key);
@@ -335,7 +339,7 @@ gpm_prefs_setup_time_combo (GpmPrefs *prefs, const gchar *widget_name,
 static void
 gpm_prefs_close_cb (GtkWidget *widget, GpmPrefs *prefs)
 {
-	egg_debug ("emitting action-close");
+	g_debug ("emitting action-close");
 	g_signal_emit (prefs, signals [ACTION_CLOSE], 0);
 }
 
@@ -352,74 +356,6 @@ gpm_prefs_delete_event_cb (GtkWidget *widget, GdkEvent *event, GpmPrefs *prefs)
 	return FALSE;
 }
 
-/** setup the notification page */
-static void
-prefs_setup_notification (GpmPrefs *prefs)
-{
-	gint icon_policy;
-	GtkWidget *radiobutton_icon_always;
-	GtkWidget *radiobutton_icon_present;
-	GtkWidget *radiobutton_icon_charge;
-	GtkWidget *radiobutton_icon_low;
-	GtkWidget *radiobutton_icon_never;
-	gboolean is_writable;
-
-	icon_policy = g_settings_get_enum (prefs->priv->settings, GPM_SETTINGS_ICON_POLICY);
-
-	radiobutton_icon_always = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-						  "radiobutton_notification_always"));
-	radiobutton_icon_present = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-						   "radiobutton_notification_present"));
-	radiobutton_icon_charge = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-						  "radiobutton_notification_charge"));
-	radiobutton_icon_low = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-					   "radiobutton_notification_low"));
-	radiobutton_icon_never = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-						 "radiobutton_notification_never"));
-
-	is_writable = g_settings_is_writable (prefs->priv->settings, GPM_SETTINGS_ICON_POLICY);
-	gtk_widget_set_sensitive (radiobutton_icon_always, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_present, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_charge, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_low, is_writable);
-	gtk_widget_set_sensitive (radiobutton_icon_never, is_writable);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_always),
-					  icon_policy == GPM_ICON_POLICY_ALWAYS);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_present),
-					  icon_policy == GPM_ICON_POLICY_PRESENT);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_charge),
-					  icon_policy == GPM_ICON_POLICY_CHARGE);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_low),
-					  icon_policy == GPM_ICON_POLICY_LOW);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_never),
-					  icon_policy == GPM_ICON_POLICY_NEVER);
-
-	g_object_set_data (G_OBJECT (radiobutton_icon_always), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_ALWAYS));
-	g_object_set_data (G_OBJECT (radiobutton_icon_present), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_PRESENT));
-	g_object_set_data (G_OBJECT (radiobutton_icon_charge), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_CHARGE));
-	g_object_set_data (G_OBJECT (radiobutton_icon_low), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_LOW));
-	g_object_set_data (G_OBJECT (radiobutton_icon_never), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_NEVER));
-
-	/* only connect the callbacks after we set the value, else the settings
-	 * keys gets written to (for a split second), and the icon flickers. */
-	g_signal_connect (radiobutton_icon_always, "clicked",
-			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
-	g_signal_connect (radiobutton_icon_present, "clicked",
-			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
-	g_signal_connect (radiobutton_icon_charge, "clicked",
-			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
-	g_signal_connect (radiobutton_icon_low, "clicked",
-			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
-	g_signal_connect (radiobutton_icon_never, "clicked",
-			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
-}
-
 static void
 prefs_setup_ac (GpmPrefs *prefs)
 {
@@ -460,7 +396,7 @@ prefs_setup_ac (GpmPrefs *prefs)
 					  button_lid_actions);
 
 	/* setup brightness slider */
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "hscale_ac_brightness"));
+	widget = GET_WIDGET ("hscale_ac_brightness");
 	g_settings_bind (prefs->priv->settings, GPM_SETTINGS_BRIGHTNESS_AC,
 			 gtk_range_get_adjustment (GTK_RANGE (widget)), "value",
 			 G_SETTINGS_BIND_DEFAULT);
@@ -468,30 +404,22 @@ prefs_setup_ac (GpmPrefs *prefs)
 			  G_CALLBACK (gpm_prefs_format_percentage_cb), NULL);
 
 	/* set up the checkboxes */
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_ac_display_dim"));
 	g_settings_bind (prefs->priv->settings, GPM_SETTINGS_IDLE_DIM_AC,
-			 widget, "active",
+			 GET_WIDGET ("checkbutton_ac_display_dim"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
 
 	if (prefs->priv->has_button_lid == FALSE) {
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "hbox_ac_lid"));
-		gtk_widget_hide(widget);
+		gtk_widget_hide (GET_WIDGET ("box_ac_lid"));
 	}
 	if (prefs->priv->has_lcd == FALSE) {
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "hbox_ac_brightness"));
-
-		gtk_widget_hide(widget);
-
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_ac_display_dim"));
-
-		gtk_widget_hide(widget);
+		gtk_widget_hide (GET_WIDGET ("box_ac_brightness"));
+		gtk_widget_hide (GET_WIDGET ("checkbutton_ac_display_dim"));
 	}
 }
 
 static void
 prefs_setup_battery (GpmPrefs *prefs)
 {
-	GtkWidget *widget;
 	GtkNotebook *notebook;
 	gint page;
 
@@ -533,9 +461,8 @@ prefs_setup_battery (GpmPrefs *prefs)
 					display_times);
 
 	if (prefs->priv->has_batteries == FALSE) {
-		notebook = GTK_NOTEBOOK (gtk_builder_get_object (prefs->priv->builder, "notebook_preferences"));
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "vbox_battery"));
-		page = gtk_notebook_page_num (notebook, GTK_WIDGET (widget));
+		notebook = GET_NOTEBOOK ("notebook_preferences");
+		page = gtk_notebook_page_num (notebook, GET_WIDGET ("box_battery"));
 		gtk_notebook_remove_page (notebook, page);
 		return;
 	}
@@ -548,36 +475,27 @@ prefs_setup_battery (GpmPrefs *prefs)
 					  battery_critical_actions);
 
 	/* set up the checkboxes */
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_battery_display_reduce"));
 	g_settings_bind (prefs->priv->settings, GPM_SETTINGS_BACKLIGHT_BATTERY_REDUCE,
-			 widget, "active",
+			 GET_WIDGET ("checkbutton_battery_display_reduce"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_battery_display_dim"));
 	g_settings_bind (prefs->priv->settings, GPM_SETTINGS_IDLE_DIM_BATT,
-			 widget, "active",
+			 GET_WIDGET ("checkbutton_battery_display_dim"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_battery_keyboard_reduce"));
 	g_settings_bind (prefs->priv->settings, GPM_SETTINGS_KBD_BACKLIGHT_BATT_REDUCE,
-			 widget, "active",
+			 GET_WIDGET ("checkbutton_battery_keyboard_reduce"), "active",
 			 G_SETTINGS_BIND_DEFAULT);
 
-	if (prefs->priv->has_button_lid == FALSE) {
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "hbox_battery_lid"));
+	if (prefs->priv->has_button_lid == FALSE)
+		gtk_widget_hide (GET_WIDGET ("box_battery_lid"));
 
-		gtk_widget_hide(widget);
-	}
-	if (prefs->priv->has_lcd == FALSE) {
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "checkbutton_battery_display_dim"));
-		gtk_widget_hide(widget);
-	}
+	if (prefs->priv->has_lcd == FALSE)
+		gtk_widget_hide (GET_WIDGET ("checkbutton_battery_display_dim"));
 }
 
 static void
 prefs_setup_ups (GpmPrefs *prefs)
 {
-	GtkWidget *widget;
 	GtkWidget *notebook;
-	GtkWidget *window;
 	gint page;
 
 	const GpmActionPolicy ups_low_actions[] =
@@ -609,16 +527,15 @@ prefs_setup_ups (GpmPrefs *prefs)
 					GPM_SETTINGS_SLEEP_DISPLAY_UPS,
 					display_times);
 
-	window = gpm_window (prefs);
-	notebook = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "notebook_preferences"));
+	notebook = GET_WIDGET ("notebook_preferences");
 	gtk_widget_add_events (notebook, GDK_SCROLL_MASK);
-	g_signal_connect (GTK_NOTEBOOK (notebook), "scroll-event",
-			  G_CALLBACK (gpm_dialog_page_scroll_event_cb),
-			  window);
+	g_signal_connect (GTK_NOTEBOOK (notebook),
+	                  "scroll-event",
+			  G_CALLBACK (gpm_notebook_scroll_event_cb),
+			  NULL);
 
 	if (prefs->priv->has_ups == FALSE) {
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "vbox_ups"));
-		page = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), GTK_WIDGET (widget));
+		page = gtk_notebook_page_num (GTK_NOTEBOOK (notebook), GET_WIDGET ("box_ups"));
 		gtk_notebook_remove_page (GTK_NOTEBOOK (notebook), page);
 		return;
 	}
@@ -634,7 +551,6 @@ prefs_setup_ups (GpmPrefs *prefs)
 static void
 prefs_setup_general (GpmPrefs *prefs)
 {
-	GtkWidget *widget;
 	const GpmActionPolicy power_button_actions[] =
 				{GPM_ACTION_POLICY_INTERACTIVE,
 				 GPM_ACTION_POLICY_SUSPEND,
@@ -655,11 +571,8 @@ prefs_setup_general (GpmPrefs *prefs)
 					  GPM_SETTINGS_BUTTON_SUSPEND,
 					  suspend_button_actions);
 
-	if (prefs->priv->has_button_suspend == FALSE) {
-		widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "hbox_general_suspend"));
-
-		gtk_widget_hide(widget);
-	}
+	if (prefs->priv->has_button_suspend == FALSE)
+		gtk_widget_hide (GET_WIDGET ("box_general_suspend"));
 }
 
 /**
@@ -669,9 +582,6 @@ prefs_setup_general (GpmPrefs *prefs)
 static void
 gpm_prefs_init (GpmPrefs *prefs)
 {
-	GtkWidget *main_window;
-	GtkWidget *widget;
-	guint retval;
 	GError *error = NULL;
 	GPtrArray *devices = NULL;
 	UpDevice *device;
@@ -705,7 +615,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 						       NULL,
 						       &error );
 		if (proxy == NULL) {
-			egg_error("Error connecting to dbus - %s", error->message);
+			g_error ("Error connecting to dbus - %s", error->message);
 			g_error_free (error);
 			return;
 		}
@@ -722,7 +632,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 			prefs->priv->can_shutdown = g_strcmp0(r,"yes")==0?TRUE:FALSE;
 			g_variant_unref (res);
 		} else if (error != NULL ) {
-			egg_error ("Error in dbus - %s", error->message);
+			g_error ("Error in dbus - %s", error->message);
 			g_error_free (error);
 		}
 
@@ -738,7 +648,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 			prefs->priv->can_suspend = g_strcmp0(r,"yes")==0?TRUE:FALSE;
 			g_variant_unref (res);
 		} else if (error != NULL ) {
-			egg_error ("Error in dbus - %s", error->message);
+			g_error ("Error in dbus - %s", error->message);
 			g_error_free (error);
 		}
 
@@ -754,7 +664,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 			prefs->priv->can_hibernate = g_strcmp0(r,"yes")==0?TRUE:FALSE;
 			g_variant_unref (res);
 		} else if (error != NULL ) {
-			egg_error ("Error in dbus - %s", error->message);
+			g_error ("Error in dbus - %s", error->message);
 			g_error_free (error);
 		}
 		g_object_unref(proxy);
@@ -776,7 +686,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 						       NULL,
 						       &error );
 		if (proxy == NULL) {
-			egg_error("Error connecting to dbus - %s", error->message);
+			g_error ("Error connecting to dbus - %s", error->message);
 			g_error_free (error);
 			return;
 		}
@@ -796,7 +706,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 			g_variant_unref (inner);
 			g_variant_unref (res);
 		} else if (error != NULL ) {
-			egg_error ("Error in dbus - %s", error->message);
+			g_error ("Error in dbus - %s", error->message);
 			g_error_free (error);
 		}
 		g_object_unref(proxy);
@@ -826,38 +736,76 @@ gpm_prefs_init (GpmPrefs *prefs)
 
 	error = NULL;
 	prefs->priv->builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_resource (prefs->priv->builder, "/org/mate/powermanager/preferences/gpm-prefs.ui", &error);
+	(void) gtk_builder_add_from_resource (prefs->priv->builder, "/org/mate/powermanager/preferences/gpm-prefs.ui", &error);
 
 	if (error) {
-		egg_error ("failed to load ui: %s", error->message);
+		g_error ("failed to load ui: %s", error->message);
 	}
 
-	main_window = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "dialog_preferences"));
-
 	/* Hide window first so that the dialogue resizes itself without redrawing */
-	gtk_widget_hide (main_window);
-	gtk_window_set_default_icon_name (GPM_ICON_APP_ICON);
+	gtk_widget_hide (GET_WIDGET ("dialog_preferences"));
 
-	/* Get the main window quit */
-	g_signal_connect (main_window, "delete_event",
-			  G_CALLBACK (gpm_prefs_delete_event_cb), prefs);
+	gtk_widget_hide (GET_WIDGET ("button_defaults"));
 
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "button_close"));
-	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpm_prefs_close_cb), prefs);
+	/** setup the notification page */
+	gint icon_policy;
+	GtkWidget *radiobutton_icon_always;
+	GtkWidget *radiobutton_icon_present;
+	GtkWidget *radiobutton_icon_charge;
+	GtkWidget *radiobutton_icon_low;
+	GtkWidget *radiobutton_icon_never;
 
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "button_help"));
-	g_signal_connect (widget, "clicked",
-			  G_CALLBACK (gpm_prefs_help_cb), prefs);
+	icon_policy = g_settings_get_enum (prefs->priv->settings, GPM_SETTINGS_ICON_POLICY);
 
-	widget = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "button_defaults"));
-	gtk_widget_hide (widget);
+	radiobutton_icon_always = GET_WIDGET ("radiobutton_notification_always");
+	radiobutton_icon_present = GET_WIDGET ("radiobutton_notification_present");
+	radiobutton_icon_charge = GET_WIDGET ("radiobutton_notification_charge");
+	radiobutton_icon_low = GET_WIDGET ("radiobutton_notification_low");
+	radiobutton_icon_never = GET_WIDGET ("radiobutton_notification_never");
+
+	gtk_widget_set_sensitive (GET_WIDGET ("box_general_notification"),
+	                          g_settings_is_writable (prefs->priv->settings, GPM_SETTINGS_ICON_POLICY));
+
+	switch (icon_policy) {
+		case GPM_ICON_POLICY_ALWAYS:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_always), TRUE);
+			break;
+		case GPM_ICON_POLICY_PRESENT:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_present), TRUE);
+			break;
+		case GPM_ICON_POLICY_CHARGE:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_charge), TRUE);
+			break;
+		case GPM_ICON_POLICY_LOW:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_low), TRUE);
+			break;
+		case GPM_ICON_POLICY_NEVER:
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_never), TRUE);
+			break;
+	}
+
+	g_object_set_data (G_OBJECT (radiobutton_icon_always), "policy", GINT_TO_POINTER (GPM_ICON_POLICY_ALWAYS));
+	g_object_set_data (G_OBJECT (radiobutton_icon_present), "policy", GINT_TO_POINTER (GPM_ICON_POLICY_PRESENT));
+	g_object_set_data (G_OBJECT (radiobutton_icon_charge), "policy", GINT_TO_POINTER (GPM_ICON_POLICY_CHARGE));
+	g_object_set_data (G_OBJECT (radiobutton_icon_low), "policy", GINT_TO_POINTER (GPM_ICON_POLICY_LOW));
+	g_object_set_data (G_OBJECT (radiobutton_icon_never), "policy", GINT_TO_POINTER (GPM_ICON_POLICY_NEVER));
+
+	gtk_builder_add_callback_symbols (prefs->priv->builder,
+	                                  "on_dialog_preferences_delete_event", G_CALLBACK (gpm_prefs_delete_event_cb),
+	                                  "on_button_help_clicked", G_CALLBACK (gpm_prefs_help_cb),
+	                                  "on_button_close_clicked", G_CALLBACK (gpm_prefs_close_cb),
+	                                  "on_radiobutton_notification_never_clicked", G_CALLBACK (gpm_prefs_icon_radio_cb),
+	                                  "on_radiobutton_notification_low_clicked", G_CALLBACK (gpm_prefs_icon_radio_cb),
+	                                  "on_radiobutton_notification_charge_clicked", G_CALLBACK (gpm_prefs_icon_radio_cb),
+	                                  "on_radiobutton_notification_present_clicked", G_CALLBACK (gpm_prefs_icon_radio_cb),
+	                                  "on_radiobutton_notification_always_clicked", G_CALLBACK (gpm_prefs_icon_radio_cb),
+	                                  NULL);
+	gtk_builder_connect_signals (prefs->priv->builder, prefs);
 
 	prefs_setup_ac (prefs);
 	prefs_setup_battery (prefs);
 	prefs_setup_ups (prefs);
 	prefs_setup_general (prefs);
-	prefs_setup_notification (prefs);
 }
 
 /**
@@ -901,5 +849,5 @@ gpm_prefs_new (void)
 GtkWidget *
 gpm_window (GpmPrefs *prefs)
 {
-	return GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder, "dialog_preferences"));
+	return GET_WIDGET ("dialog_preferences");
 }
