@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -25,7 +26,6 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 #include "egg-test.h"
-#include "egg-debug.h"
 
 #include "gpm-screensaver.h"
 
@@ -52,7 +52,6 @@ main (int argc, char **argv)
 	EggTest *test;
 
 	test = egg_test_init ();
-	egg_debug_init (TRUE);
 
 	/* needed for DPMS checks */
 	gtk_init (&argc, &argv);
