@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -30,7 +31,6 @@
 #include <dbus/dbus-glib.h>
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
 #include "egg-color.h"
 #include "egg-array-float.h"
 
@@ -503,8 +503,7 @@ gpm_stats_update_info_page_history (UpDevice *device)
 	gboolean points;
 	GpmPointObj *point;
 	GPtrArray *new;
-	gint32 offset = 0;
-	GTimeVal timeval;
+	gint32 offset;
 
 	new = g_ptr_array_new_with_free_func ((GDestroyNotify) gpm_point_obj_free);
 	if (g_strcmp0 (history_type, GPM_HISTORY_CHARGE_VALUE) == 0) {
@@ -551,8 +550,7 @@ gpm_stats_update_info_page_history (UpDevice *device)
 	gtk_widget_hide (widget);
 	gtk_widget_show (graph_history);
 
-	g_get_current_time (&timeval);
-	offset = timeval.tv_sec;
+	offset = (gint32) (g_get_real_time () / G_USEC_PER_SEC);
 
 	for (i=0; i<array->len; i++) {
 		item = (UpHistoryItem *) g_ptr_array_index (array, i);
@@ -562,7 +560,7 @@ gpm_stats_update_info_page_history (UpDevice *device)
 			continue;
 
 		point = gpm_point_obj_new ();
-		point->x = (gint32) up_history_item_get_time (item) - offset;
+		point->x = ((gint32) up_history_item_get_time (item)) - offset;
 		point->y = up_history_item_get_value (item);
 		if (up_history_item_get_state (item) == UP_DEVICE_STATE_CHARGING)
 			point->color = egg_color_from_rgb (255, 0, 0);
@@ -828,7 +826,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean dat
 		g_settings_set_string (settings, GPM_SETTINGS_INFO_LAST_DEVICE, current_device);
 
 		/* show transaction_id */
-		egg_debug ("selected row is: %s", current_device);
+		g_debug ("selected row is: %s", current_device);
 
 		/* is special device */
 		device = up_device_new ();
@@ -837,7 +835,7 @@ gpm_stats_devices_treeview_clicked_cb (GtkTreeSelection *selection, gboolean dat
 		g_object_unref (device);
 
 	} else {
-		egg_debug ("no row selected");
+		g_debug ("no row selected");
 	}
 }
 
@@ -863,7 +861,7 @@ gpm_stats_device_changed_cb (UpDevice *device, GParamSpec *pspec, gpointer user_
 	object_path = up_device_get_object_path (device);
 	if (object_path == NULL || current_device == NULL)
 		return;
-	egg_debug ("changed:   %s", object_path);
+	g_debug ("changed:   %s", object_path);
 	if (g_strcmp0 (current_device, object_path) == 0)
 		gpm_stats_update_info_data (device);
 }
@@ -876,7 +874,6 @@ gpm_stats_add_device (UpDevice *device, GPtrArray *devices)
 {
 	const gchar *id;
 	GtkTreeIter iter;
-	const gchar *text;
 	const gchar *icon;
 	UpDeviceKind kind;
 	gchar *label, *vendor, *model;
@@ -921,7 +918,7 @@ gpm_stats_device_added_cb (UpClient *client, UpDevice *device, GPtrArray *device
 {
 	const gchar *object_path;
 	object_path = up_device_get_object_path (device);
-	egg_debug ("added:     %s", object_path);
+	g_debug ("added:     %s", object_path);
 
 	gpm_stats_add_device (device, devices);
 }
@@ -946,7 +943,7 @@ gpm_stats_device_removed_cb (UpClient *client, const gchar *object_path, GPtrArr
 			break;
 		}
 	}
-	egg_debug ("removed:   %s", object_path);
+	g_debug ("removed:   %s", object_path);
 	if (g_strcmp0 (current_device, object_path) == 0) {
 		gtk_list_store_clear (list_store_info);
 	}
@@ -1192,7 +1189,6 @@ gpm_stats_highlight_device (const gchar *object_path)
 int
 main (int argc, char *argv[])
 {
-	gboolean verbose = FALSE;
 	GOptionContext *context;
 	GtkBox *box;
 	GtkWidget *widget, *window;
@@ -1207,13 +1203,8 @@ main (int argc, char *argv[])
 	gint page;
 	gboolean checked;
 	gchar *last_device = NULL;
-	guint retval;
-	GError *error = NULL;
 
 	const GOptionEntry options[] = {
-		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
-		  /* TRANSLATORS: show verbose debugging */
-		  N_("Show extra debugging information"), NULL },
 		{ "device", '\0', 0, G_OPTION_ARG_STRING, &last_device,
 		  /* TRANSLATORS: show a device by default */
 		  N_("Select this device at startup"), NULL },
@@ -1235,7 +1226,6 @@ main (int argc, char *argv[])
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
-	egg_debug_init (verbose);
 	gtk_init (&argc, &argv);
 
 	app = gtk_application_new ("org.mate.PowerManager.Statistics", 0);
@@ -1251,12 +1241,7 @@ main (int argc, char *argv[])
 	settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 
 	/* get UI */
-	builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_resource (builder, "/org/mate/powermanager/statistics/gpm-statistics.ui", &error);
-
-	if (error) {
-		egg_error ("failed to load ui: %s", error->message);
-	}
+	builder = gtk_builder_new_from_resource ("/org/mate/powermanager/statistics/gpm-statistics.ui");
 
 	/* add history graph */
 	box = GTK_BOX (gtk_builder_get_object (builder, "hbox_history"));
@@ -1313,9 +1298,10 @@ main (int argc, char *argv[])
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "notebook1"));
 
 	gtk_widget_add_events (widget, GDK_SCROLL_MASK);
-	g_signal_connect (widget, "scroll-event",
-	                  G_CALLBACK (gpm_dialog_page_scroll_event_cb),
-	                  window);
+	g_signal_connect (widget,
+	                  "scroll-event",
+	                  G_CALLBACK (gpm_notebook_scroll_event_cb),
+	                  NULL);
 
 	page = g_settings_get_int (settings, GPM_SETTINGS_INFO_PAGE_NUMBER);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), page);
