@@ -2,6 +2,7 @@
  *
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  * Copyright (C) 2005-2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -21,7 +22,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <stdlib.h>
@@ -40,8 +41,6 @@
 #include <gtk/gtk.h>
 #include <libupower-glib/upower.h>
 
-#include "egg-debug.h"
-
 #include "gpm-upower.h"
 #include "gpm-engine.h"
 #include "gpm-common.h"
@@ -120,7 +119,7 @@ gpm_tray_icon_set_icon (GpmTrayIcon *icon, const gchar *icon_name)
 	g_return_val_if_fail (GPM_IS_TRAY_ICON (icon), FALSE);
 
 	if (icon_name != NULL) {
-		egg_debug ("Setting icon to %s", icon_name);
+		g_debug ("Setting icon to %s", icon_name);
 		gtk_status_icon_set_from_icon_name (icon->priv->status_icon,
 		                                    icon_name);
 
@@ -128,7 +127,7 @@ gpm_tray_icon_set_icon (GpmTrayIcon *icon, const gchar *icon_name)
 		gpm_tray_icon_show (icon, TRUE);
 	} else {
 		/* remove icon */
-		egg_debug ("no icon will be displayed");
+		g_debug ("no icon will be displayed");
 
 		/* make sure that we are hidden */
 		gpm_tray_icon_show (icon, FALSE);
@@ -148,7 +147,7 @@ gpm_tray_icon_show_info_cb (GtkMenuItem *item, gpointer data)
 	object_path = g_object_get_data (G_OBJECT (item), "object-path");
 	path = g_strdup_printf ("%s/mate-power-statistics --device %s", BINDIR, object_path);
 	if (!g_spawn_command_line_async (path, NULL))
-		egg_warning ("Couldn't execute command: %s", path);
+		g_warning ("Couldn't execute command: %s", path);
 	g_free (path);
 }
 
@@ -162,7 +161,7 @@ gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 	const gchar *command = "mate-power-preferences";
 
 	if (g_spawn_command_line_async (command, NULL) == FALSE)
-		egg_warning ("Couldn't execute command: %s", command);
+		g_warning ("Couldn't execute command: %s", command);
 }
 
 #define ABOUT_GROUP "About"
@@ -204,7 +203,7 @@ gpm_tray_icon_show_about_cb (GtkMenuItem *item, gpointer data)
 				"program-name", _("Power Manager"),
 				"version", VERSION,
 				"comments", _("Power management daemon"),
-				"copyright", _("Copyright \xC2\xA9 2011-2020 MATE developers"),
+				"copyright", _("Copyright \xC2\xA9 2011-2021 MATE developers"),
 				"authors", authors,
 				/* Translators should localize the following string
 				* which will be displayed at the bottom of the about
@@ -213,7 +212,7 @@ gpm_tray_icon_show_about_cb (GtkMenuItem *item, gpointer data)
 				"translator-credits", _("translator-credits"),
 				"icon-name", "mate-power-manager",
 				"logo-icon-name", "mate-power-manager",
-				"website", "https://mate-desktop.org",
+				"website", PACKAGE_URL,
 				NULL);
 
 	g_strfreev (authors);
@@ -263,7 +262,7 @@ gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *arr
 			continue;
 
 		object_path = up_device_get_object_path (device);
-		egg_debug ("adding device %s", object_path);
+		g_debug ("adding device %s", object_path);
 		added++;
 
 		/* generate the label */
@@ -374,7 +373,7 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon)
 	g_signal_connect (G_OBJECT (item), "activate",
 			  G_CALLBACK (gpm_tray_icon_show_preferences_cb), icon);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-	
+
 	/*Set up custom panel menu theme support-gtk3 only */
 	GtkWidget *toplevel = gtk_widget_get_toplevel (GTK_WIDGET (menu));
 	/* Fix any failures of compiz/other wm's to communicate with gtk for transparency in menu theme */
@@ -409,7 +408,7 @@ static void
 gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
 {
 	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
-	egg_debug ("clear tray");
+	g_debug ("clear tray");
 	g_object_ref_sink (widget);
 	g_object_unref (widget);
 }
@@ -444,7 +443,7 @@ gpm_tray_icon_popup_menu (GpmTrayIcon *icon, guint32 timestamp)
 static void
 gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 timestamp, GpmTrayIcon *icon)
 {
-	egg_debug ("icon right clicked");
+	g_debug ("icon right clicked");
 	gpm_tray_icon_popup_menu (icon, timestamp);
 }
 
@@ -458,7 +457,7 @@ gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 t
 static void
 gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon, GpmTrayIcon *icon)
 {
-	egg_debug ("icon left clicked");
+	g_debug ("icon left clicked");
 	gpm_tray_icon_popup_menu (icon, gtk_get_current_event_time());
 }
 
