@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2006-2007 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  *
  * This program is free software; you can redistribute it and/or
@@ -32,8 +33,6 @@
 
 #include "gsd-media-keys-window.h"
 
-#define MSD_MEDIA_KEYS_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), MSD_TYPE_MEDIA_KEYS_WINDOW, MsdMediaKeysWindowPrivate))
-
 #define ICON_SCALE 0.55           /* size of the icon compared to the whole OSD */
 
 struct MsdMediaKeysWindowPrivate
@@ -49,7 +48,7 @@ struct MsdMediaKeysWindowPrivate
         GtkWidget               *progress;
 };
 
-G_DEFINE_TYPE (MsdMediaKeysWindow, msd_media_keys_window, MSD_TYPE_OSD_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (MsdMediaKeysWindow, msd_media_keys_window, MSD_TYPE_OSD_WINDOW)
 
 static void
 volume_controls_set_visible (MsdMediaKeysWindow *window,
@@ -645,19 +644,12 @@ msd_media_keys_window_class_init (MsdMediaKeysWindowClass *klass)
         MsdOsdWindowClass *osd_window_class = MSD_OSD_WINDOW_CLASS (klass);
 
         osd_window_class->draw_when_composited = msd_media_keys_window_draw_when_composited;
-
-        g_type_class_add_private (klass, sizeof (MsdMediaKeysWindowPrivate));
 }
 
 static void
 msd_media_keys_window_init (MsdMediaKeysWindow *window)
 {
-        GdkScreen *screen;
-
-        window->priv = MSD_MEDIA_KEYS_WINDOW_GET_PRIVATE (window);
-
-        screen = gtk_widget_get_screen (GTK_WIDGET (window));
-
+        window->priv = msd_media_keys_window_get_instance_private (window);
         if (!msd_osd_window_is_composited (MSD_OSD_WINDOW (window))) {
                 GtkBuilder *builder;
                 const gchar *objects[] = {"acme_box", NULL};
